@@ -1,5 +1,7 @@
 from typing import Any
 
+from .item import Item, ItemType
+
 
 class BaseDict(dict):
     """Dictionary with pretty :py:func:`__repr__` output.
@@ -54,6 +56,16 @@ class BidirectionalDict(BaseDict):
         super(BidirectionalDict, self).__setitem__(key, value)
         super(BidirectionalDict, self).__setitem__(value, key)
 
+    def update(self, dictionary: dict = {}, **kwargs):
+        super(BidirectionalDict, self).update(
+            {
+                **dictionary,
+                **{v: k for k, v in dictionary.items()},
+                **kwargs,
+                **{v: k for k, v in kwargs.items()},
+            }
+        )
+
 
 class ObjectDict(BaseDict):
     """Dictionary that can be accessed as though it was an object.
@@ -94,16 +106,16 @@ class OverloadedDict(BaseDict):
     """
 
     def __add__(self, other: dict) -> dict:
-        d = {**self, **other}
-        return OverloadedDict(d)
+        dct = {**self, **other}
+        return OverloadedDict(dct)
 
     def __iadd__(self, other: dict) -> dict:
         self = self.__add__(other)
         return self
 
     def __sub__(self, other: dict) -> dict:
-        d = {k: v for k, v in self.items() if (k, v) not in other.items()}
-        return OverloadedDict(d)
+        dct = {k: v for k, v in self.items() if (k, v) not in other.items()}
+        return OverloadedDict(dct)
 
     def __isub__(self, other: dict) -> dict:
         self = self.__sub__(other)
@@ -153,3 +165,52 @@ class FrozenDict(BaseDict):
     def __setitem__(self, key, value):
         err = "Cannot set key and value because this is a frozen dictionary."
         raise KeyError(err)
+
+    def update(self, dictionary: dict = {}, **kwargs):
+        err = "Cannot set key and value because this is a frozen dictionary."
+        raise KeyError(err)
+
+
+class ItemDict(BaseDict):
+    """Dictionary composed of :py:class:`toolbox.collections.item.Item` key and values.
+
+    Example:
+
+        .. code-block:: python
+
+            from toolbox.collections.mapping import ItemDict
+
+            d = ItemDict({"100": "one hundred"})
+            print(d)
+            # >>> <ItemDict {Item(bytes=b'100', str='100', int=100, bool=True, original_type=str): Item(bytes=b'one hundred', str='one hundred', int=None, bool=True, original_type=str)}>
+
+            print(d["100"] == d[100] == d[b"100"]) # >>> True
+    """
+
+    def __init__(self, dictionary: dict = {}, **kwargs):
+        super(ItemDict, self).__init__(
+            {
+                **{Item(k): Item(v) for k, v in dictionary.items()},
+                **{Item(k): Item(v) for k, v in kwargs.items()},
+            }
+        )
+
+    def __getitem__(self, key: ItemType):
+        return super(ItemDict, self).__getitem__(Item(key))
+
+    def __setitem__(self, key: ItemType, value: ItemType):
+        super(ItemDict, self).__setitem__(Item(key), Item(value))
+
+    def __delitem__(self, key: ItemType):
+        super(ItemDict, self).__delitem__(Item(key))
+
+    def __contains__(self, key: ItemType):
+        return super(ItemDict, self).__contains__(Item(key))
+
+    def update(self, dictionary: dict = {}, **kwargs):
+        super(ItemDict, self).update(
+            {
+                **{Item(k): Item(v) for k, v in dictionary.items()},
+                **{Item(k): Item(v) for k, v in kwargs.items()},
+            },
+        )
